@@ -13,6 +13,9 @@ class SassCompiler(object):
         if mimetype == 'text/scss':
             args.append('--scss')
 
+        if cwd:
+            args += ['-I', cwd]
+
         handler = subprocess.Popen(args, stdout=subprocess.PIPE, stdin=subprocess.PIPE,
                                    stderr=subprocess.PIPE, cwd=None)
 
@@ -22,3 +25,4 @@ class SassCompiler(object):
             return handler.stdout.read()
         else:
             raise RuntimeError('Test this :S %s' % handler.stderr.read())
+
